pub fn redfish_map_err<E>(error: E) -> Responsewhere
E: Display,Expand description
The same as redfish_map_err_no_log, but also create a tracing event for the error.
pub fn redfish_map_err<E>(error: E) -> Responsewhere
E: Display,The same as redfish_map_err_no_log, but also create a tracing event for the error.