pub struct MediaControllerCollection {
pub odata_context: Option<Context>,
pub odata_etag: Option<Etag>,
pub odata_id: Id,
pub odata_type: Type,
pub description: Option<Description>,
pub members: Vec<IdRef>,
pub members_odata_count: Count,
pub members_odata_next_link: Option<NextLink>,
pub name: Name,
pub oem: Option<Oem>,
}Expand description
The collection of MediaController resource instances.
Fields
odata_context: Option<Context>odata_etag: Option<Etag>odata_id: Idodata_type: Typedescription: Option<Description>members: Vec<IdRef>The members of this collection.
members_odata_count: Countmembers_odata_next_link: Option<NextLink>name: Nameoem: Option<Oem>Trait Implementations
Sourceimpl Clone for MediaControllerCollection
impl Clone for MediaControllerCollection
Sourcefn clone(&self) -> MediaControllerCollection
fn clone(&self) -> MediaControllerCollection
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MediaControllerCollection
impl Debug for MediaControllerCollection
Sourceimpl Default for MediaControllerCollection
impl Default for MediaControllerCollection
Sourcefn default() -> MediaControllerCollection
fn default() -> MediaControllerCollection
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for MediaControllerCollection
impl<'de> Deserialize<'de> for MediaControllerCollection
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<MediaControllerCollection, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<MediaControllerCollection, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Metadata<'static> for MediaControllerCollection
impl Metadata<'static> for MediaControllerCollection
Sourceconst JSON_SCHEMA: &'static str = "MediaControllerCollection.json"
const JSON_SCHEMA: &'static str = "MediaControllerCollection.json"
Name of the json-schema file that describes the entity that implements this trait. Should
be only the file name, so that it can be resolved relative to the URL of the redfish
service, or the public Redfish schema index.
Sourceimpl Serialize for MediaControllerCollection
impl Serialize for MediaControllerCollection
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more