pub struct ResetRequestBody {
pub reset_type: Option<ResetType>,
}Expand description
This action resets the processor.
Fields
reset_type: Option<ResetType>Trait Implementations
Sourceimpl Clone for ResetRequestBody
impl Clone for ResetRequestBody
Sourcefn clone(&self) -> ResetRequestBody
fn clone(&self) -> ResetRequestBody
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResetRequestBody
impl Debug for ResetRequestBody
Sourceimpl Default for ResetRequestBody
impl Default for ResetRequestBody
Sourcefn default() -> ResetRequestBody
fn default() -> ResetRequestBody
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ResetRequestBody
impl<'de> Deserialize<'de> for ResetRequestBody
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ResetRequestBody, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ResetRequestBody, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Metadata<'static> for ResetRequestBody
impl Metadata<'static> for ResetRequestBody
Sourceconst JSON_SCHEMA: &'static str = "Processor.v1_18_0.json"
const JSON_SCHEMA: &'static str = "Processor.v1_18_0.json"
Name of the json-schema file that describes the entity that implements this trait. Should
be only the file name, so that it can be resolved relative to the URL of the redfish
service, or the public Redfish schema index.
Sourceimpl Serialize for ResetRequestBody
impl Serialize for ResetRequestBody
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more