pub struct SensorExcerpt {
pub data_source_uri: Option<String>,
pub reading: Option<f64>,
}Expand description
The Sensor schema describes a sensor and its properties.
Fields
data_source_uri: Option<String>The link to the resource that provides the data for this sensor.
reading: Option<f64>The sensor value.