pub struct SensorArrayExcerpt {
pub data_source_uri: Option<String>,
pub device_name: Option<String>,
pub physical_context: Option<PhysicalContext>,
pub physical_sub_context: Option<PhysicalSubContext>,
pub reading: Option<f64>,
}Expand description
The Sensor schema describes a sensor and its properties.
Fields
data_source_uri: Option<String>The link to the resource that provides the data for this sensor.
device_name: Option<String>The name of the device.
physical_context: Option<PhysicalContext>physical_sub_context: Option<PhysicalSubContext>reading: Option<f64>The sensor value.