pub struct SimpleStorageCollection {
pub odata_context: Option<Context>,
pub odata_etag: Option<Etag>,
pub odata_id: Id,
pub odata_type: Type,
pub description: Option<Description>,
pub members: Vec<IdRef>,
pub members_odata_count: Count,
pub members_odata_next_link: Option<NextLink>,
pub name: Name,
pub oem: Option<Oem>,
}Expand description
The SimpleStorageCollection schema contains a collection of simple storage instances.
Fields
odata_context: Option<Context>odata_etag: Option<Etag>odata_id: Idodata_type: Typedescription: Option<Description>members: Vec<IdRef>The members of this collection.
members_odata_count: Countmembers_odata_next_link: Option<NextLink>name: Nameoem: Option<Oem>Trait Implementations
Sourceimpl Clone for SimpleStorageCollection
impl Clone for SimpleStorageCollection
Sourcefn clone(&self) -> SimpleStorageCollection
fn clone(&self) -> SimpleStorageCollection
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SimpleStorageCollection
impl Debug for SimpleStorageCollection
Sourceimpl Default for SimpleStorageCollection
impl Default for SimpleStorageCollection
Sourcefn default() -> SimpleStorageCollection
fn default() -> SimpleStorageCollection
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SimpleStorageCollection
impl<'de> Deserialize<'de> for SimpleStorageCollection
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<SimpleStorageCollection, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<SimpleStorageCollection, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Metadata<'static> for SimpleStorageCollection
impl Metadata<'static> for SimpleStorageCollection
Sourceconst JSON_SCHEMA: &'static str = "SimpleStorageCollection.json"
const JSON_SCHEMA: &'static str = "SimpleStorageCollection.json"
Name of the json-schema file that describes the entity that implements this trait. Should
be only the file name, so that it can be resolved relative to the URL of the redfish
service, or the public Redfish schema index.
Sourceimpl Serialize for SimpleStorageCollection
impl Serialize for SimpleStorageCollection
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more