pub struct CacheSummary {
pub persistent_cache_size_mi_b: Option<i64>,
pub status: Option<Status>,
pub total_cache_size_mi_b: i64,
}Expand description
This type describes the cache memory of the storage controller in general detail.
Fields
persistent_cache_size_mi_b: Option<i64>The portion of the cache memory that is persistent, measured in MiB.
status: Option<Status>total_cache_size_mi_b: i64The total configured cache memory, measured in MiB.