Seuss is a set of components and entities for implementing Redfish-compliant services. This crate combines the redfish_codegen and redfish_axum crates–which are generated programmatically from the Redfish schema bundle and standard registries–with some basic implementations of common services and components to provide a batteries-included suite of tools for implementing Redfish compliant services on POSIX and non-POSIX systems.
Modules
- Components for authenticating and authorizing users.
- Re-exports from redfish_axum.
- Re-exports from redfish_core.
- Utilities for reporting Redfish errors to users.
- Middleware that can be used with the axum ecosystem (mostly used internally).
- Implementations of some standard components.
Structs
- Constructs an HTTP response with the Link header set to the path of the json-schema document describing the Redfish model contained in the response body.
- Constructs an HTTP response from a Redfish model instance.
Constants
- The OData Version supported by this version of the redfish data model.
- The version of the Redfish Schema Specification provided by this crate.
- The base URL of the Redfish json-schema files.
Traits
- Metadata about a model.