pub struct NetworkDeviceFunctionMetrics {Show 25 fields
pub odata_context: Option<Context>,
pub odata_etag: Option<Etag>,
pub odata_id: Id,
pub odata_type: Type,
pub actions: Option<Actions>,
pub description: Option<Description>,
pub ethernet: Option<Ethernet>,
pub fibre_channel: Option<FibreChannel>,
pub id: Id,
pub name: Name,
pub oem: Option<Oem>,
pub rx_avg_queue_depth_percent: Option<f64>,
pub rx_bytes: Option<i64>,
pub rx_frames: Option<i64>,
pub rx_multicast_frames: Option<i64>,
pub rx_queues_empty: Option<bool>,
pub rx_queues_full: Option<i64>,
pub rx_unicast_frames: Option<i64>,
pub tx_avg_queue_depth_percent: Option<f64>,
pub tx_bytes: Option<i64>,
pub tx_frames: Option<i64>,
pub tx_multicast_frames: Option<i64>,
pub tx_queues_empty: Option<bool>,
pub tx_queues_full: Option<i64>,
pub tx_unicast_frames: Option<i64>,
}Expand description
The NetworkDeviceFunctionMetrics schema contains usage and health statistics for a network function of a network adapter.
Fields
odata_context: Option<Context>odata_etag: Option<Etag>odata_id: Idodata_type: Typeactions: Option<Actions>description: Option<Description>ethernet: Option<Ethernet>fibre_channel: Option<FibreChannel>id: Idname: Nameoem: Option<Oem>rx_avg_queue_depth_percent: Option<f64>The average RX queue depth as the percentage.
rx_bytes: Option<i64>The total number of bytes received on a network function.
rx_frames: Option<i64>The total number of frames received on a network function.
rx_multicast_frames: Option<i64>The total number of good multicast frames received on a network function since reset.
rx_queues_empty: Option<bool>Whether nothing is in a network function’s RX queues to DMA.
rx_queues_full: Option<i64>The number of RX queues that are full.
rx_unicast_frames: Option<i64>The total number of good unicast frames received on a network function since reset.
tx_avg_queue_depth_percent: Option<f64>The average TX queue depth as the percentage.
tx_bytes: Option<i64>The total number of bytes sent on a network function.
tx_frames: Option<i64>The total number of frames sent on a network function.
tx_multicast_frames: Option<i64>The total number of good multicast frames transmitted on a network function since reset.
tx_queues_empty: Option<bool>Whether all TX queues for a network function are empty.
tx_queues_full: Option<i64>The number of TX queues that are full.
tx_unicast_frames: Option<i64>The total number of good unicast frames transmitted on a network function since reset.